@@ -163,6 +163,8 @@ pub(crate) fn parse_l2(market_type: MarketType, msg: &str) -> Result<Vec<OrderBo
             pair: pair.clone(),
             msg_type: MessageType::L2Event,
             timestamp,
+            seq_id: None,
+            prev_seq_id: None,
             asks: raw_orderbook.asks.iter().map(|x| parse_order(x)).collect(),
             bids: raw_orderbook.bids.iter().map(|x| parse_order(x)).collect(),
             snapshot,
