@@ -124,6 +124,8 @@ pub(crate) fn parse_l2(market_type: MarketType, msg: &str) -> Result<Vec<OrderBo
         pair: pair.to_string(),
         msg_type: MessageType::L2Event,
         timestamp,
+        seq_id: None,
+        prev_seq_id: None,
         asks: ws_msg.data.asks.iter().map(|x| parse_order(x)).collect(),
         bids: ws_msg.data.bids.iter().map(|x| parse_order(x)).collect(),
         snapshot,
