@@ -153,6 +153,8 @@ pub(crate) fn parse_l2(msg: &str) -> Result<Vec<OrderBookMsg>> {
                     pair,
                     msg_type: MessageType::L2Event,
                     timestamp,
+                    seq_id: None,
+                    prev_seq_id: None,
                     asks,
                     bids,
                     snapshot,
@@ -202,6 +204,8 @@ pub(crate) fn parse_l2(msg: &str) -> Result<Vec<OrderBookMsg>> {
             pair,
             msg_type: MessageType::L2Event,
             timestamp,
+            seq_id: None,
+            prev_seq_id: None,
             asks,
             bids,
             snapshot,
